# Orca
#
# Copyright 2006 Sun Microsystems Inc.
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Library General Public
# License as published by the Free Software Foundation; either
# version 2 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Library General Public License for more details.
#
# You should have received a copy of the GNU Library General Public
# License along with this library; if not, write to the
# Free Software Foundation, Inc., 59 Temple Place - Suite 330,
# Boston, MA 02111-1307, USA.

"""Custom script for gnome_segv2."""

__id__        = "$Id: gnome_segv2.py 3123 2007-10-19 21:15:28Z richb $"
__version__   = "$Revision: 3123 $"
__date__      = "$Date: 2007-10-19 17:15:28 -0400 (Fri, 19 Oct 2007) $"
__copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
__license__   = "LGPL"

import orca.default as default

########################################################################
#                                                                      #
# The gnome_segv2 script class.                                            #
#                                                                      #
########################################################################

class Script(default.Script):

    def __init__(self, app):
        """Creates a new script for the given application.

        Arguments:
        - app: the application to create a script for.
        """

        default.Script.__init__(self, app)

    def locusOfFocusChanged(self, event, oldLocusOfFocus, newLocusOfFocus):
        """Called when the visual object with focus changes.

        Arguments:
        - event: if not None, the Event that caused the change
        - oldLocusOfFocus: Accessible that is the old locus of focus
        - newLocusOfFocus: Accessible that is the new locus of focus
        """

        # If the gnome_segv2 application is running it's probably because
        # some application has crashed unexpectedly. If we just called
        # locusOfFocusChanged() in default.py we would hang (see bug #344192).
        # To circumvent this, we set the old locus of focus to None, then
        # we can safely call the locusOfFocusChanged() method in default.py.
        #
        default.Script.locusOfFocusChanged(self, event, None, newLocusOfFocus)
